@@ -18,7 +18,7 @@
  * along with Small File Renamer.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @brief  Functions to modify file names
- * 
+ *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
 #include <string.h>
@@ -36,21 +36,20 @@ name_delete_chars (RenData             *rd_data,
     ProcessData pd_data = {
         NULL,
         NULL,
-        rd_data->del->pos,
-        rd_data->del->cnt,
+        rdelete_get_pos (rendata_get_rdelete (rd_data)),
+        rdelete_get_cnt (rendata_get_rdelete (rd_data)),
         0,
         0,
         0
     };
 
     /* exit if no chars to delete */
-    if (rd_data->del->cnt == 0)
-        return;
-
-    string_process_filename (string_delete_chars,
-                             rd_data->names->rf_items[i]->s_new,
-                             &pd_data,
-                             rd_data->applyto);
+    if (rdelete_get_cnt (rendata_get_rdelete (rd_data))) {
+        string_process_filename (string_delete_chars,
+                                 rd_data->names->rf_items[i]->s_new,
+                                 &pd_data,
+                                 rendata_get_applyto (rd_data));
+    }
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -61,22 +60,21 @@ name_insert_string (RenData             *rd_data,
                     const uint_fast32_t  i)
 {
     ProcessData pd_data = {
-        rd_data->ins->s_text,
+        rinsovr_get_text (rendata_get_rinsert (rd_data)),
         NULL,
-        rd_data->ins->pos,
+        rinsovr_get_pos (rendata_get_rinsert (rd_data)),
         0,
         0,
         0,
         0
     };
 
-    if (strcmp (rd_data->ins->s_text, "") == 0)
-        return;
-
-    string_process_filename (string_insert_string,
-                             rd_data->names->rf_items[i]->s_new,
-                             &pd_data,
-                             rd_data->applyto);
+    if (!rinsovr_empty (rendata_get_rinsert (rd_data))) {
+        string_process_filename (string_insert_string,
+                                 rd_data->names->rf_items[i]->s_new,
+                                 &pd_data,
+                                 rendata_get_applyto (rd_data));
+    }
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -87,22 +85,21 @@ name_overwrite_string (RenData             *rd_data,
                        const uint_fast32_t  i)
 {
     ProcessData pd_data = {
-        rd_data->ovrw->s_text,
+        rinsovr_get_text (rendata_get_roverwr (rd_data)),
         NULL,
-        (size_t) rd_data->ovrw->pos,
+        (size_t) rinsovr_get_pos (rendata_get_roverwr (rd_data)),
         0,
         0,
         0,
         0
     };
 
-    if (strcmp (rd_data->ovrw->s_text, "") == 0)
-        return;
-
-    string_process_filename (string_overwrite_string,
-                             rd_data->names->rf_items[i]->s_new,
-                             &pd_data,
-                             rd_data->applyto);
+    if (!rinsovr_empty (rendata_get_roverwr (rd_data))) {
+        string_process_filename (string_overwrite_string,
+                                 rd_data->names->rf_items[i]->s_new,
+                                 &pd_data,
+                                 rendata_get_applyto (rd_data));
+    }
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -115,18 +112,18 @@ name_number_string (RenData             *rd_data,
     ProcessData pd_data = {
         NULL,
         NULL,
-        (size_t) rd_data->number->pos,
+        (size_t) rnumber_get_pos (rendata_get_rnumber (rd_data)),
         0,
         i,
-        rd_data->number->start,
-        rd_data->names->cnt - 1
+        rnumber_get_start (rendata_get_rnumber (rd_data)),
+        rfnames_get_cnt (rendata_get_rfnames (rd_data)) - 1
     };
 
-    if (rd_data->number->opt) {
+    if (rnumber_get_opt (rendata_get_rnumber (rd_data))) {
         string_process_filename (string_add_number,
                                  rd_data->names->rf_items[i]->s_new,
                                  &pd_data,
-                                 rd_data->applyto);
+                                 rendata_get_applyto (rd_data));
     }
 }
 /*----------------------------------------------------------------------------*/
@@ -140,19 +137,18 @@ name_to_upcase_lowercase (RenData             *rd_data,
     ProcessData pd_data = { NULL, NULL, 0, 0, 0, 0, 0 };
 
     /* to uppercase */
-    if (rd_data->uplo == 0) {
+    if (rendata_get_uplo (rd_data) == 0) {
         string_process_filename (string_to_upper,
                                  rd_data->names->rf_items[i]->s_new,
                                  &pd_data,
-                                 rd_data->applyto);
+                                 rendata_get_applyto (rd_data));
     }
-
     /* to lowercase */
-    if (rd_data->uplo == 1) {
+    else if (rendata_get_uplo (rd_data) == 1) {
         string_process_filename (string_to_lower,
                                  rd_data->names->rf_items[i]->s_new,
                                  &pd_data,
-                                 rd_data->applyto);
+                                 rendata_get_applyto (rd_data));
     }
 }
 /*----------------------------------------------------------------------------*/
@@ -165,20 +161,20 @@ name_spaces_underscores (RenData             *rd_data,
                          const uint_fast32_t  i)
 {
     /* underscores to spaces */
-    if (rd_data->spaces == 0) {
+    if (rendata_get_spaces (rd_data) == 0) {
         ProcessData pd_data = { "_", " ", 0, 0, 0, 0, 0 };
         string_process_filename (string_replace_in,
                                  rd_data->names->rf_items[i]->s_new,
                                  &pd_data,
-                                 rd_data->applyto);
+                                 rendata_get_applyto (rd_data));
     }
     /* spaces to underscores */
-    if (rd_data->spaces == 1) {
+    else if (rendata_get_spaces (rd_data) == 1) {
         ProcessData pd_data = { " ", "_", 0, 0, 0, 0, 0 };
         string_process_filename (string_replace_in,
                                  rd_data->names->rf_items[i]->s_new,
                                  &pd_data,
-                                 rd_data->applyto);
+                                 rendata_get_applyto (rd_data));
     }
 }
 /*----------------------------------------------------------------------------*/
@@ -191,8 +187,8 @@ name_replace_strings (RenData             *rd_data,
                       const uint_fast32_t  i)
 {
     ProcessData pd_data = {
-        rd_data->replace->s_from,
-        rd_data->replace->s_to,
+        rreplace_get_from (rendata_get_rreplace (rd_data)),
+        rreplace_get_to (rendata_get_rreplace (rd_data)),
         0,
         0,
         0,
@@ -200,11 +196,11 @@ name_replace_strings (RenData             *rd_data,
         0
     };
 
-    if (strcmp (rd_data->replace->s_from, "") != 0) {
+    if (!rreplace_empty_from (rendata_get_rreplace (rd_data))) {
         string_process_filename (string_replace_in,
                                  rd_data->names->rf_items[i]->s_new,
                                  &pd_data,
-                                 rd_data->applyto);
+                                 rendata_get_applyto (rd_data));
     }
 }
 /*----------------------------------------------------------------------------*/
