@@ -18,7 +18,7 @@
  * along with Small File Renamer.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @brief  RenData struncture with data to rename files.
- * 
+ *
  * @author Michał Bąbik <michalb1981@o2.pl>
  */
 #ifndef RENDATA_H
@@ -28,78 +28,10 @@
 #include <stdint.h>
 #include "rfnames.h"
 #include "defs.h"
-/*----------------------------------------------------------------------------*/
-/**
- * @struct RDelete
- *
- * @brief  Delete text in name string settings
- *
- * @var   RDelete::cnt
- * @brief Delete chars count
- *
- * @var   RDelete::pos
- * @brief Delete chars starting position
- */
-typedef struct
-RDelete {
-    uint8_t   cnt;
-    uint8_t   pos;
-} RDelete;
-/*----------------------------------------------------------------------------*/
-/**
- * @struct RInsOvr
- *
- * @brief  Insert / Overwrite text in name settings
- *
- * @var   RInsOvr::s_text
- * @brief String to insert / Overwrite name
- *
- * @var   RInsOvr::pos
- * @brief Position to put string
- */
-typedef struct
-RInsOvr {
-    char      s_text [FN_LEN + 1];
-    uint8_t   pos;
-} RInsOvr;
-/*----------------------------------------------------------------------------*/
-/**
- * @struct RReplace
- *
- * @brief  Replace strings in name settings
- *
- * @var   RReplace::s_from
- * @brief Replace from string
- *
- * @var   RReplace::s_to
- * @brief Replace to string
- */
-typedef struct
-RReplace {
-    char      s_from [FN_LEN + 1];
-    char      s_to   [FN_LEN + 1];
-} RReplace;
-/*----------------------------------------------------------------------------*/
-/**
- * @struct RNumber
- *
- * @brief  Number names settigns
- *
- * @var   RNumber::opt
- * @brief If opt is 0 numbering is disabled, if opt is not 0 it is enabled
- *
- * @var   RNumber::start
- * @brief Start numbering from value start
- *
- * @var   RNumber::pos
- * @brief Number position in string
- */
-typedef struct
-RNumber {
-    int8_t        opt;
-    uint_fast32_t start;
-    uint8_t       pos;
-} RNumber;
+#include "rdelete.h"
+#include "rinsovr.h"
+#include "rreplace.h"
+#include "rnumber.h"
 /*----------------------------------------------------------------------------*/
 /** 
  * @struct RenData
@@ -130,7 +62,7 @@ RNumber {
  * @brief Apply to file names/ext or both option
  * @var   RenData::renexit
  * @brief Exit after rename option
- * @var   RenData::i_opt
+ * @var   RenData::dirsel
  * @brief Select files from directory options
  */ 
 typedef struct
@@ -145,7 +77,7 @@ RenData {
     int8_t     spaces;   /* Spaces/underscores option */
     int8_t     applyto;  /* Apply to file names/ext or both option */
     int8_t     renexit;  /* Exit after rename option */
-    int8_t     i_opt;    /* Select files from directory options */
+    int8_t     dirsel;   /* Select files from directory options */
 } RenData;
 /*----------------------------------------------------------------------------*/
 /**
@@ -155,7 +87,7 @@ RenData {
  *
  * @fn         void rendata_free (RenData *rd_data)
  * @brief      Free allocated memory.
- * @param[out] rd_data Pointer to RenData object
+ * @param[out] rd_data RenData object
  * @return     none
  */
 /*----------------------------------------------------------------------------*/
@@ -169,7 +101,105 @@ void      rendata_free (RenData *rd_data);
  * @param[in] rd_data RenData object with RFnames list
  * @return    RFnames item
  */
-RFnames * rendata_get_names (const RenData *rd_data) __attribute__ ((pure));
+const RFnames * rendata_get_rfnames (const RenData *rd_data)
+                __attribute__ ((pure));
+const RDelete * rendata_get_rdelete (const RenData *rd_data)
+                __attribute__ ((pure));
+const RInsOvr * rendata_get_rinsert (const RenData *rd_data)
+                __attribute__ ((pure));
+const RInsOvr * rendata_get_roverwr (const RenData *rd_data)
+                __attribute__ ((pure));
+const RReplace * rendata_get_rreplace (const RenData *rd_data)
+                __attribute__ ((pure));
+const RNumber * rendata_get_rnumber (const RenData *rd_data)
+                __attribute__ ((pure));
+/*----------------------------------------------------------------------------*/
+/**
+ * @fn         int8_t rendata_get_uplo (const RenData *rd_data)
+ * @brief      Get uplo value.
+ * @param[in]  rd_data  RenData object
+ * @return     uplo value
+ *
+ * @fn         void rendata_set_uplo (RenData *rd_data,
+ *                                    int8_t   val)
+ * @brief      Set uplo value.
+ * @param[out] rd_data  RenData object
+ * @param[in]  val      New uplo value
+ * @return     none
+ *
+ * @fn         int8_t rendata_get_spaces (const RenData *rd_data)
+ * @brief      Get spaces value.
+ * @param[in]  rd_data  RenData object
+ * @return     spaces value
+ *
+ * @fn         void rendata_set_spaces (RenData *rd_data,
+ *                                      int8_t   val)
+ * @brief      Set spaces value.
+ * @param[out] rd_data  RenData object
+ * @param[in]  val      New spaces value
+ * @return     none
+ *
+ * @fn         int8_t rendata_get_applyto (const RenData *rd_data)
+ * @brief      Get applyto value.
+ * @param[in]  rd_data  RenData object
+ * @return     applyto value
+ *
+ * @fn         void rendata_set_applyto (RenData *rd_data,
+ *                                       int8_t   val)
+ * @brief      Set applyto value.
+ * @param[out] rd_data  RenData object
+ * @param[in]  val      New applyto value
+ * @return     none
+ *
+ * @fn         int8_t rendata_get_renexit (const RenData *rd_data)
+ * @brief      Get renexit value.
+ * @param[in]  rd_data  RenData object
+ * @return     renexit value
+ *
+ * @fn         void rendata_set_renexit (RenData *rd_data,
+ *                                       int8_t   val)
+ * @brief      Set renexit value.
+ * @param[out] rd_data  RenData object
+ * @param[in]  val      New renexit value
+ * @return     none
+ *
+ * @fn         int8_t rendata_get_dirsel (const RenData *rd_data)
+ * @brief      Get dirsel value.
+ * @param[in]  rd_data  RenData object
+ * @return     dirsel value
+ *
+ * @fn         void rendata_set_dirsel  (RenData *rd_data,
+ *                                       int8_t   val)
+ * @brief      Set dirsel value.
+ * @param[out] rd_data  RenData object
+ * @param[in]  val      New dirsel value
+ * @return     none
+ */
+/*----------------------------------------------------------------------------*/
+int8_t    rendata_get_uplo    (const RenData *rd_data) __attribute__ ((pure));
+
+void      rendata_set_uplo    (RenData       *rd_data,
+                               int8_t         val);
+
+int8_t    rendata_get_spaces  (const RenData *rd_data) __attribute__ ((pure));
+
+void      rendata_set_spaces  (RenData       *rd_data,
+                               int8_t         val);
+
+int8_t    rendata_get_applyto (const RenData *rd_data) __attribute__ ((pure));
+
+void      rendata_set_applyto (RenData       *rd_data,
+                               int8_t         val);
+
+int8_t    rendata_get_renexit (const RenData *rd_data) __attribute__ ((pure));
+
+void      rendata_set_renexit (RenData       *rd_data,
+                               int8_t         val);
+
+int8_t    rendata_get_dirsel  (const RenData *rd_data) __attribute__ ((pure));
+
+void      rendata_set_dirsel  (RenData       *rd_data,
+                               int8_t         val);
 /*----------------------------------------------------------------------------*/
 #endif
 
