@@ -133,7 +133,7 @@ str_compare (const char *a,
 static void
 rfitem_label_set_markup (RFitem *rf_item)
 {
-    char s_mark[100];
+    char s_mark [100];
     s_mark[0] = '\0';
 
     strcpy (s_mark, "<span font_family=\"monospace\"");
@@ -327,6 +327,45 @@ rfitem_delete (RFitem *rf_item)
     free (rf_item);
 }
 /*----------------------------------------------------------------------------*/
+const char *
+rfitem_get_snew (const RFitem *rf_item)
+{
+    return (const char *) rf_item->s_new;
+}
+/*----------------------------------------------------------------------------*/
+void
+rfitem_set_snew (RFitem     *rf_item,
+                 const char *val)
+{
+    strcpy (rf_item->s_new, val);
+}
+/*----------------------------------------------------------------------------*/
+const char *
+rfitem_get_sorg (const RFitem *rf_item)
+{
+    return (const char *) rf_item->s_org;
+}
+/*----------------------------------------------------------------------------*/
+void
+rfitem_set_sorg (RFitem     *rf_item,
+                 const char *val)
+{
+    strcpy (rf_item->s_org, val);
+}
+/*----------------------------------------------------------------------------*/
+const char *
+rfitem_get_spth (const RFitem *rf_item)
+{
+    return (const char *) rf_item->s_pth;
+}
+/*----------------------------------------------------------------------------*/
+void
+rfitem_set_spth (RFitem     *rf_item,
+                 const char *val)
+{
+    strcpy (rf_item->s_pth, val);
+}
+/*----------------------------------------------------------------------------*/
 /**
  * @brief  Restore original file name button clicked.
  */
